<?php
/**
 * @link              https://dialectpro.org
 * @since             3.0.0
 * @package           Dictionary_Pro
 *
 * @dictionary-pro
 * Plugin Name:       Dictionary Pro
 * Plugin URI:        https://dialectpro.org/resources/dictionary
 * Description:       A full-featured, elegant solution for maintaining a custom dictionary.
 * Version:           3.1.2
 * Author:            Anne Dorko
 * Author URI:        https://www.annedorko.com/
 * Text Domain:       dictionary-pro
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * License Keys
 *
 * Get the license key, set a secret password if none exists
 */
// update_option( 'dictionary_pro_license', '' );
$dpro_license = get_option( 'dictionary_pro_license' );
if ( empty( $dpro_license ) ) {
	// Set a unique password based on the URL if none is set
	$unique_password = md5( get_bloginfo( 'url' ) );
	$dpro_license = array();
	$dpro_license['instance_password'] = $unique_password;
	update_option( 'dictionary_pro_license', $dpro_license );
}
define( 'DICTIONARY_PRO_SECRET_KEY', $dpro_license['instance_password'] );
define( 'DICTIONARY_PRO_API_SERVER', 'https://dialectpro.org/?wc-api=am-software-api' );
define( 'DICTIONARY_PRO_REFERENCE', 'Dictionary Pro' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-dictionary-pro-activator.php
 */
function activate_dictionary_pro() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dictionary-pro-activator.php';
	Dictionary_Pro_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-dictionary-pro-deactivator.php
 */
function deactivate_dictionary_pro() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dictionary-pro-deactivator.php';
	Dictionary_Pro_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_dictionary_pro' );
register_deactivation_hook( __FILE__, 'deactivate_dictionary_pro' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-dictionary-pro.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    3.0.0
 */
define( 'WPD_DIRECTORY', plugin_dir_path( __FILE__ ) );
define( 'WPD_BASENAME', plugin_basename( __FILE__ ) );
function run_dictionary_pro() {
	$plugin = new Dictionary_Pro();
	$plugin->run();
}
// Kickoff
run_dictionary_pro();
