<?php

class WP_Dictionary_Settings {

	private $tab;
	private $dictionary;
	private $page_title;
	private $menu_title;
	private $url;
	private $tabs;
	private $sections = array();
	private $fields = array();

	function __construct( $dictionary = '' ) {
		if ( empty( $dictionary ) || ! is_object( $dictionary ) ) { return false; }

		$this->dictionary = $dictionary;
		$this->set_vars();
	}

	public function url() {
		return $this->url;
	}
	public function page_title() {
		return $this->page_title;
	}
	public function menu_title() {
		return $this->menu_title;
	}
	public function tabs() {
		return $this->tabs;
	}
	public function sections() {
		return $this->sections;
	}
	public function fields() {
		return $this->fields;
	}

	function current_tab( $tab = '' ) {
		$tab = $this->dictionary->slug() . '-general';
		if ( isset( $_GET['tab'] ) && ! empty( $_GET['tab'] ) ) {
			$tab = $_GET['tab'];
		}
		return sanitize_title( $tab );
	}

	function set_vars() {
		$labels = $this->dictionary->default_labels();
		$settings_translation = __( 'Settings', 'dictionary-pro' );
		$this->page_title = $labels['menu_name'] . ' ' . $settings_translation;
		$this->menu_title = $settings_translation;
		$this->url = 'edit.php?post_type=' . $this->dictionary->slug();
		$this->tabs = array(
			$this->dictionary->slug() . '-general' => array(
				'label' => __( 'General', 'dictionary-pro' ),
		'icon' => 'admin-settings',
			),
			$this->dictionary->slug() . '-appearance' => array(
				'label' => __( 'Appearance', 'dictionary-pro' ),
			'icon' => 'admin-appearance',
			),
			$this->dictionary->slug() . '-advanced' => array(
				'label' => __( 'Advanced', 'dictionary-pro' ),
			'icon' => 'admin-tools',
			),
		);
	}

	function validate_tab_options( $input ) {

		$options = $this->dictionary->options();

		// Check for false checkboxes ( makes checkboxes work with tabs )
		if ( isset( $input['checkbox'] ) and is_array( $input['checkbox'] ) ) {
			foreach ( $input['checkbox'] as $checkboxes ) {
				if ( ! isset( $input[ $checkboxes ] ) || false === $input[ $checkboxes ] ) {
					$input[ $checkboxes ] = false;
				}
			}
			unset( $input['checkbox'] );
		}

		if ( is_array( $input ) and ! empty( $input ) ) {
			// Only update inputs that have incoming values
			foreach ( $input as $key => $changed ) {
				$options[ $key ] = $changed;
				// Flush permalinks when the permalink changes
				if ( false !== strpos( $key, 'enable_permalinks' ) ) {
					$flush = true;
				}
				// Delete transients for magic linking changes
				if ( false !== strpos( $key, 'enable_post_links' ) ) {
					delete_transient( $this->dictionary->slug() . '_entries_automagic_keys' );
				}
			}
			if ( isset( $flush ) && true === $flush ) {
				// Rewrite permalinks if a slug was set
				// NOTE: This is recorded as bad practice, look for alternatives
				flush_rewrite_rules( false );
			}
		}
		return $options;
	}

	/**
	 * Functions for adding sections and options from the outside
	 */

	function new_tab( $uid ) {
		$this->tabs[ $uid ] = $uid;
		return $this->tabs;
	}

	function add_section( $tab, $uid, $label, $callback = '' ) {
		// TODO: Validate tabs, sanitize, etc.
		$this->sections[ $uid ] = array( 'uid' => $uid, 'label' => $label, 'tab' => $tab, 'callback' => $callback );
		return $this->sections;
	}

	function add_field( $section, $uid, $label, $callback = '' ) {
		// TODO: Validate tabs, sanitize, etc.
		$this->fields[ $section ][ $uid ] = array( 'uid' => $uid, 'label' => $label, 'callback' => $callback );
		return $this->sections;
	}


	/**
	 * Functions for registering new sections and options
	 */

	function register_settings() {
		foreach ( $this->sections as $section_uid => $section_values ) {
			$this->new_section( $section_uid, $section_values['label'], $section_values['tab'] );
		}
	}

	function new_section( $uid, $label, $tab ) {
		add_settings_section( $uid, $label, array( $this, 'section_callback' ), $tab );
		if ( isset( $this->fields[ $uid ] ) ) {
			foreach ( $this->fields[ $uid ] as $field_uid => $field_values ) {
				add_settings_field(
					$field_uid,
					$field_values['label'],
					array( $this, 'fields_callback' ),
					$tab,
					$uid,
				array( 'section_uid' => $uid, 'field_uid' => $field_uid ) );
			}
		}
		register_setting( $tab, $this->dictionary->option_name(), array( $this, 'validate_tab_options' ) );
	}

	function section_callback( $args ) {
		$id = $args['id'];
		$callback = $this->sections[ $id ]['callback'];
		$this->function_or_string( $callback );
	}

	function fields_callback( $args ) {
		$section = $args['section_uid'];
		$field = $args['field_uid'];
		$callback = $this->fields[ $section ][ $field ]['callback'];
		$this->function_or_string( $callback, $field );
	}

	function function_or_string( $callback, $field = '' ) {

		if ( is_callable( $callback ) ) {
			$string = $callback( $this->dictionary );
		} else {
			$string = $callback;
		}

		$do_not_format = array( 'field_order', 'fields' );
		if ( false !== strpos( $string, '<input' ) && false === in_array( $field, $do_not_format ) ) {
			$string = $this->set_input_defaults( $string, $field );
		}

		echo $string;
	}

	function set_input_defaults( $string, $field ) {
		$option_name = $this->dictionary->option_name();
		$options = $this->dictionary->options();
		$field_name = $option_name . '[' . $field . ']';

		$string = preg_replace( '/<input /', '<input name="' . $field_name . '" id="' . $field . '" ', $string, 1 );

		if ( false !== strpos( $string, 'type="checkbox"' ) ) {
			// Detect CHECKED value
			if ( isset( $options[ $field ] ) and ! empty( $options[ $field ] ) ) {
				$checked = ( $options[ $field ] ) ? 'checked' : '';
				$string = str_replace( '<input ', "<input $checked ", $string );
			}
			// Add trick for confirming checkboxes that are empty
			$string .= '<input type="hidden" name="' . $option_name . '[checkbox][]" value="' . $field . '" />';
		}
		if ( false !== strpos( $string, 'value=""' ) ) {
			$value = '';
			if ( isset( $options[ $field ] ) and ! empty( $options[ $field ] ) ) {
				$value = $options[ $field ];
				$string = str_replace( 'value=""', 'value="' . $value . '"', $string );
			}
		}
		return $string;
	}

	/**
	 * Enable License Checks
	 */

	public function activate_license( $license ) {
		global $version, $error;
		$version = $this->version;
		$error = '';
		// Check for form submission
		if ( $_REQUEST && isset( $_REQUEST['license_key'] ) ) {
			// Basic validation
			if ( empty( $_REQUEST['license_key'] ) ) {
				$error = __( 'Please enter a license key.', 'dictionary-pro' );
			}
			if ( empty( $_REQUEST['license_email'] ) ) {
				$error = __( 'Please enter the email registered with Dialect Pro.', 'dictionary-pro' );
			}
			if ( empty( $error ) ) {
				$license_key = $_REQUEST['license_key'];
				$license_email = $_REQUEST['license_email'];

				/**
				 * https://docs.woocommerce.com/document/woocommerce-api-manager/
				 */
				$api_params = array(
					'request' 	=> 'activation',
					'email'		=> $license_email,
					'licence_key' => $license_key,
					'product_id' => DICTIONARY_PRO_REFERENCE,
					'platform'	=> $this->remove_http( get_bloginfo( 'url' ) ),
					'instance'	=> DICTIONARY_PRO_SECRET_KEY,
					'software_version'	=> $version,
				);
				$query = esc_url_raw( add_query_arg( $api_params, DICTIONARY_PRO_API_SERVER ) );
				$response = wp_remote_get( $query, array( 'sslverify' => true ) );

				if ( is_wp_error( $response ) ) {
								$error = __( 'Unexpected error! The query returned with an error. Please email us at hello@dialectpro.org', 'dictionary-pro' );
				} else {
					$license_data = json_decode( wp_remote_retrieve_body( $response ) );
					if ( null === $license_data ) {
						$error = 'There was an error connecting to the server, try again in a few minutes.';
					} elseif ( isset( $license_data->activated ) && 'inactive' === $license_data->activated ) {
						$error = '';
						if ( isset( $license_data->error ) ) {
							$error = $license_data->error . ' ';
						}
						if ( isset( $license_data->{'additional info'} ) ) {
							$error .= $license_data->{'additional info'};
						}
					} elseif ( isset( $license_data->activated ) && true == $license_data->activated ) {
						// Success!
						$dpro_license = get_option( 'dictionary_pro_license' );
						$dpro_license['license_key'] = $license_key;
						$dpro_license['license_email'] = $license_email;
						update_option( 'dictionary_pro_license', $dpro_license );
						wp_redirect( admin_url( '/edit.php?post_type=dictionary' ) );
								exit;
					} else {
						$error = '';
						if ( isset( $license_data->error ) ) {
							$error = $license_data->error . ' ';
						}
						if ( isset( $license_data->{'additional info'} ) ) {
							$error .= $license_data->{'additional info'};
						}
					}
				}
			}
		}
	}
}
