<?php
/**
 * Basic class for adding Widgets
 */

class Dictionary_Pro_Widget extends WP_Widget {

	public function __construct() {
		// Requires WordPress 4.3
		$widget_options = array(
			'classname' => 'dictionary recent-entries',
			'description' => __( 'Displays the most recent dictionary entries.', 'dictionary-pro' ),
		);
		parent::__construct( 'recent_wpd_entries', __( 'Recent Entries', 'dictionary-pro' ), $widget_options );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters( 'widget_title', $instance['title'] );
		$num_posts = ! $instance['num_posts'] ? '5' : $instance['num_posts'];

		// Get recent dictionary entries
		$recent_args = array(
		'numberposts'  => intval( $num_posts ),
		'post_type'     => 'dictionary',
		'orderby'       => 'post_date',
		);

		$recent_entries = get_posts( $recent_args );

		// Widget output
		echo $before_widget;
		echo ! empty( $title ) ? ($before_title . $title . $after_title) : '';
		?>
			<ul>
		<?php
		foreach ( $recent_entries as $entry ) { ?>
	      <li><a href="<?php echo get_permalink( $entry->ID ); ?>" title="<?php _e( 'Definition for', 'wpd_language' ); ?> <?php echo $entry->post_title; ?>"><?php echo $entry->post_title; ?></a></li>
		    <?php }
		?>
			</ul>
			<?php
			echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		// Save widget options
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['num_posts'] = $new_instance['num_posts'];
		return $instance;
	}

	function form( $instance ) {
		// Output admin widget options form
		if ( $instance ) {
			$title = esc_attr( $instance['title'] );
			$num_posts = esc_attr( $instance['num_posts'] );
		} else {
			$title = '';
			$num_posts = 5;
		}
		?>
			<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wpd_language' ); ?></label>
	  		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"></p>
		  <p><label for="<?php echo $this->get_field_id( 'num_posts' ); ?>"><?php _e( 'Number of entries to show:', 'wpd_language' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'num_posts' ); ?>" name="<?php echo $this->get_field_name( 'num_posts' ); ?>" type="text" value="<?php echo $num_posts; ?>" size="3"></p>
			<?php
	}
}
